@@ -4,6 +4,7 @@ Toxopy (https://github.com/bchaselab/Toxopy)
 Licensed under the terms of the MIT license
 """
 
+import os
 import pandas as pd
 from math import sqrt
 from numpy import nan
@@ -12,8 +13,7 @@ from rich.console import Console
 from pathlib import Path
 from glob import glob
 from toxopy import trials
-import os
-import shutil
+from shutil import move
 
 
 def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
@@ -30,7 +30,7 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
 
         cat = Path(cat_head).stem[:-5]
 
-        console.print(f'Cat ==> {cat} :cat2:', style='bold red')
+        console.print(f'\nCAT ==> {cat.upper()} :cat2:', style='bold red')
 
         def improve_dlc_csv(csv_file, trial_type, file_name):
             """Add time and trial type."""
@@ -59,7 +59,7 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
                         tls.append('FT')
                     else:
                         for q, p in zip(range(0, 4), trls[2:][::2]):
-                            if tt[q] < i < tt[q+1]:
+                            if tt[q] <= i < tt[q+1]:
                                 tls.append(p)
 
             elif trial_type == "cat":
@@ -89,7 +89,7 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
         if only_improve_csv is True:
             return None
 
-        """Calculate distance between cat and owner."""
+        """Calculate the distance between cat and owner."""
 
         def dt(file_name):
             improved = f'{output_dir}/{Path(file_name).stem}_improved.csv'
@@ -115,7 +115,7 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
 
             ds.append(distance)
 
-        df_owner['distance'] = ds
+        df_cat['distance'] = ds
 
         def renameCols(i, j):
             i.rename(columns={'x': f'x_{j}', 'y': f'y_{j}'}, inplace=True)
@@ -123,8 +123,8 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
         renameCols(df_cat, 'cat'), renameCols(df_owner, 'owner')
 
         result = pd.concat([
-            df_cat[{'indx', 'x_cat', 'y_cat'}],
-            df_owner[{'x_owner', 'y_owner', 'time', 'trial', 'distance'}]
+            df_cat[{'indx', 'x_cat', 'y_cat', 'distance'}],
+            df_owner[{'x_owner', 'y_owner', 'time', 'trial'}]
         ],
             axis=1)
 
@@ -141,7 +141,12 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
 
         for df_alt, name in zip(dfs, dfs_names):
 
-            """Calculate cat traveled distance."""
+            if name == 'WO':
+                console.print("\nW/ OWNER TRIALS", style="bold blue")
+            elif name == 'CA':
+                console.print("\nCAT ALONE TRIALS", style="bold blue")
+
+            """Calculate the cat's traveled distance."""
 
             def calculateDistance(x1, y1, x2, y2):
                 dist = sqrt((x2 - x1)**2 + (y2 - y1)**2)
@@ -191,7 +196,8 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
                 velocity_ls.append(float(calculateVelocity(d, 0.033)))
 
             fdf['velocity'] = velocity_ls
-            """Calculate cat movement state."""
+
+            """Calculate the cat's movement state."""
 
             moving, notMoving = [], []
 
@@ -243,26 +249,24 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
 
             cols = ['cat_distance', 'velocity', 'acceleration']
 
-            idx = df.index[df['indx']].tolist()
+            idx = df['indx'].tolist()
 
             console.print("\nCLEANING OUTPUT", style="bold green")
 
             for s, w in tqdm(zip(df['velocity'], idx)):
-                if s == 0:
+                if s > 100:
                     df = df.drop(w)
-                elif s > 100:
-                    df = df.drop(w)
-
-            df[cols] = df[cols].replace({0: nan})
 
             df['cat'] = cat
 
+            df = df.dropna()
+
             df.to_csv(f'{output_dir}/{cat}_{name}_improved.csv',
                       index=False,
                       sep=',',
                       encoding='utf-8')
 
-            console.print("\nDONE!", style="bold green")
+            console.print("\nDONE!\n", style="bold green")
 
         for i in ['ch', 'oh', 'chwo']:
             tbrm = glob(f'{output_dir}/*_{i}_improved.csv')
@@ -275,4 +279,4 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
         else:
             pass
         for file in glob(f'{output_dir}/*_{x}_*.csv'):
-            shutil.move(file, op)
+            move(file, op)
